@@ -615,7 +615,7 @@ class Commit(object):
         s = {
             "creator": creator,
             "fee": "%s STEEM" % float(required_fee_hive),
-            # "delegation": "%s VESTS" % required_fee_vests,
+            "delegation": "%s VESTS" % required_fee_vests,
             "json_metadata": json_meta or {},
             "memo_key": memo,
             "new_account_name": account_name,
@@ -636,7 +636,8 @@ class Commit(object):
             },
             "prefix": self.hived.chain_params["prefix"],
         }
-        op = operations.AccountCreate(**s)
+        #op = operations.AccountCreate(**s)
+        op = operations.AccountCreateWithDelegation(**s)
 
         return self.finalizeOp(op, creator, "active")
 
