@@ -18,7 +18,6 @@ from .instance import get_config_node_list
 logger = logging.getLogger(__name__)
 
 
-
 class Hived(HttpClient):
     """ Connect to the Hive network.
 
@@ -52,7 +51,7 @@ class Hived(HttpClient):
 
     def __init__(self, nodes=None, **kwargs):
         if not nodes:
-            nodes = get_config_node_list() or ['https://api.hive.blog']
+            nodes = get_config_node_list() or ["https://api.hive.blog"]
 
         super(Hived, self).__init__(nodes, **kwargs)
 
@@ -62,18 +61,17 @@ class Hived(HttpClient):
             dictionary with keys chain_id, prefix, and other chain
             specific settings
         """
-        props = self.get_dynamic_global_properties()
-        chain = props["current_supply"].split(" ")[1]
+        props = self.get_config()
+        chain_id = props["HIVE_CHAIN_ID"]
+
+        chain = None
+        for supported_chain in known_chains.values():
+            if chain_id == supported_chain["chain_id"]:
+                chain = supported_chain
+
+        if chain is None:
+            raise Exception("The chain you are connecting " + "to is not supported")
 
-        assert chain in known_chains, "The chain you are connecting " + \
-                                      "to is not supported"
-        #return known_chains.get(chain)
-        # temporarily use chain_id from get_version until after HF24
-        chain = known_chains.get(chain)
-        version = self.get_version()
-        if version['chain_id'] != '0000000000000000000000000000000000000000000000000000000000000000':
-          print('Switching to chain_id '+version['chain_id'])
-          chain['chain_id'] = version['chain_id']
         return chain
 
     def get_replies(self, author, skip_own=True):
@@ -97,7 +95,7 @@ class Hived(HttpClient):
         """
         state = self.get_state("/promoted")
         # why is there a empty key in the struct?
-        promoted = state["discussion_idx"][''].get("promoted", [])
+        promoted = state["discussion_idx"][""].get("promoted", [])
         r = []
         for p in promoted:
             post = state["content"].get(p)
@@ -124,8 +122,14 @@ class Hived(HttpClient):
             discussion_query["start_permlink"] = permlink
 
         if sort not in [
-            "trending", "created", "active", "cashout", "payout", "votes",
-            "children", "hot"
+            "trending",
+            "created",
+            "active",
+            "cashout",
+            "payout",
+            "votes",
+            "children",
+            "hot",
         ]:
             raise Exception("Invalid choice of '--sort'!")
 
@@ -141,21 +145,19 @@ class Hived(HttpClient):
             To be used in a for loop that returns an instance of `Post()`.
         """
         for c in Blockchain(
-                mode=kwargs.get("mode", "irreversible"),
-                hived_instance=self,
+            mode=kwargs.get("mode", "irreversible"), hived_instance=self,
         ).stream("comment", *args, **kwargs):
             yield Post(c, hived_instance=self)
 
     @property
     def last_irreversible_block_num(self):
         """ Newest irreversible block number. """
-        return self.get_dynamic_global_properties()[
-            'last_irreversible_block_num']
+        return self.get_dynamic_global_properties()["last_irreversible_block_num"]
 
     @property
     def head_block_number(self):
         """ Newest block number. """
-        return self.get_dynamic_global_properties()['head_block_number']
+        return self.get_dynamic_global_properties()["head_block_number"]
 
     def get_account(self, account):
         """ Lookup account information such as user profile, public keys,
@@ -168,9 +170,9 @@ class Hived(HttpClient):
             dict: Account information.
 
         """
-        return first(self.call('get_accounts', [account]))
+        return first(self.call("get_accounts", [account]))
 
-    def get_all_usernames(self, last_user=''):
+    def get_all_usernames(self, last_user=""):
         """ Fetch the full list of Hive usernames. """
         usernames = self.lookup_accounts(last_user, 1000)
         batch = []
@@ -194,10 +196,12 @@ class Hived(HttpClient):
             A generator with results.
 
         """
-        results = self.call_multi_with_futures(
-            'get_block', blocks, max_workers=10)
-        return (compat_compose_dictionary(x, block_num=int(x['block_id'][:8], base=16))
-                for x in results if x)
+        results = self.call_multi_with_futures("get_block", blocks, max_workers=10)
+        return (
+            compat_compose_dictionary(x, block_num=int(x["block_id"][:8], base=16))
+            for x in results
+            if x
+        )
 
     def get_blocks(self, block_nums):
         """ Fetch multiple blocks from hived at once, given a range.
@@ -219,7 +223,7 @@ class Hived(HttpClient):
 
         while missing:
             for block in self._get_blocks(missing):
-                blocks[block['block_num']] = block
+                blocks[block["block_num"]] = block
 
             available = set(blocks.keys())
             missing = required - available
@@ -242,7 +246,7 @@ class Hived(HttpClient):
         """
         return self.get_blocks(list(range(start, end)))
 
-    def get_reward_fund(self, fund_name='post'):
+    def get_reward_fund(self, fund_name="post"):
         """ Get details for a reward fund.
 
         Right now the only pool available is 'post'.
@@ -265,109 +269,107 @@ class Hived(HttpClient):
                  'reward_balance': '555660.895 HIVE'}
 
         """
-        return self.call('get_reward_fund', fund_name, api='database_api')
+        return self.call("get_reward_fund", fund_name, api="database_api")
 
-    def get_expiring_vesting_delegations(self, account,
-                                         start, limit):
+    def get_expiring_vesting_delegations(self, account, start, limit):
         """ get_expiring_vesting_delegations """
         return self.call(
-            'get_expiring_vesting_delegations',
+            "get_expiring_vesting_delegations",
             account,
             start,
             limit,
-            api='database_api')
+            api="database_api",
+        )
 
     def get_trending_tags(self, after_tag, limit):
         """ get_trending_tags """
-        return self.call(
-            'get_trending_tags', after_tag, limit, api='database_api')
+        return self.call("get_trending_tags", after_tag, limit, api="database_api")
 
     def get_tags_used_by_author(self, account):
         """ get_tags_used_by_author """
-        return self.call(
-            'get_tags_used_by_author', account, api='database_api')
+        return self.call("get_tags_used_by_author", account, api="database_api")
 
     def get_discussions_by_trending(self, discussion_query):
         """ get_discussions_by_trending """
         return self.call(
-            'get_discussions_by_trending',
-            discussion_query,
-            api='database_api')
+            "get_discussions_by_trending", discussion_query, api="database_api"
+        )
 
     def get_comment_discussions_by_payout(self, discussion_query):
         """ get_comment_discussions_by_payout """
         return self.call(
-            'get_comment_discussions_by_payout',
-            discussion_query,
-            api='database_api')
+            "get_comment_discussions_by_payout", discussion_query, api="database_api"
+        )
 
     def get_post_discussions_by_payout(self, discussion_query):
         """ get_post_discussions_by_payout """
         return self.call(
-            'get_post_discussions_by_payout',
-            discussion_query,
-            api='database_api')
+            "get_post_discussions_by_payout", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_created(self, discussion_query):
         """ get_discussions_by_created """
         return self.call(
-            'get_discussions_by_created', discussion_query, api='database_api')
+            "get_discussions_by_created", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_active(self, discussion_query):
         """ get_discussions_by_active """
         return self.call(
-            'get_discussions_by_active', discussion_query, api='database_api')
+            "get_discussions_by_active", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_cashout(self, discussion_query):
         """ get_discussions_by_cashout """
         return self.call(
-            'get_discussions_by_cashout', discussion_query, api='database_api')
+            "get_discussions_by_cashout", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_payout(self, discussion_query):
         """ get_discussions_by_payout """
         return self.call(
-            'get_discussions_by_payout', discussion_query, api='database_api')
+            "get_discussions_by_payout", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_votes(self, discussion_query):
         """ get_discussions_by_votes """
         return self.call(
-            'get_discussions_by_votes', discussion_query, api='database_api')
+            "get_discussions_by_votes", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_children(self, discussion_query):
         """ get_discussions_by_children """
         return self.call(
-            'get_discussions_by_children',
-            discussion_query,
-            api='database_api')
+            "get_discussions_by_children", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_hot(self, discussion_query):
         """ get_discussions_by_hot """
-        return self.call(
-            'get_discussions_by_hot', discussion_query, api='database_api')
+        return self.call("get_discussions_by_hot", discussion_query, api="database_api")
 
     def get_discussions_by_feed(self, discussion_query):
         """ get_discussions_by_feed """
         return self.call(
-            'get_discussions_by_feed', discussion_query, api='database_api')
+            "get_discussions_by_feed", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_blog(self, discussion_query):
         """ get_discussions_by_blog """
         return self.call(
-            'get_discussions_by_blog', discussion_query, api='database_api')
+            "get_discussions_by_blog", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_comments(self, discussion_query):
         """ get_discussions_by_comments """
         return self.call(
-            'get_discussions_by_comments',
-            discussion_query,
-            api='database_api')
+            "get_discussions_by_comments", discussion_query, api="database_api"
+        )
 
     def get_discussions_by_promoted(self, discussion_query):
         """ get_discussions_by_promoted """
         return self.call(
-            'get_discussions_by_promoted',
-            discussion_query,
-            api='database_api')
+            "get_discussions_by_promoted", discussion_query, api="database_api"
+        )
 
     def get_block_header(self, block_num):
         """ Get block headers, given a block number.
@@ -394,7 +396,7 @@ class Hived(HttpClient):
                  '4ddc419e531cccee6da660057d606d11aab9f3a5',
                  'witness': 'chainsquad.com'}
         """
-        return self.call('get_block_header', block_num, api='database_api')
+        return self.call("get_block_header", block_num, api="database_api")
 
     def get_block(self, block_num):
         """ Get the full block, transactions and all, given a block number.
@@ -406,24 +408,25 @@ class Hived(HttpClient):
             dict in a JSON compatible format.
 
         """
-        return self.call('get_block', block_num, api='database_api')
+        return self.call("get_block", block_num, api="database_api")
 
     def get_ops_in_block(self, block_num, virtual_only):
         """ get_ops_in_block """
         return self.call(
-            'get_ops_in_block', block_num, virtual_only, api='database_api')
+            "get_ops_in_block", block_num, virtual_only, api="database_api"
+        )
 
     def get_state(self, path):
         """ get_state """
-        return self.call('get_state', path, api='database_api')
+        return self.call("get_state", path, api="database_api")
 
     def get_config(self):
         """ Get internal chain configuration. """
-        return self.call('get_config', api='database_api')
+        return self.call("get_config", api="database_api")
 
     def get_dynamic_global_properties(self):
         """ get_dynamic_global_properties """
-        return self.call('get_dynamic_global_properties', api='database_api')
+        return self.call("get_dynamic_global_properties", api="database_api")
 
     def get_chain_properties(self):
         """ Get witness elected chain properties.
@@ -435,7 +438,7 @@ class Hived(HttpClient):
              'hbd_interest_rate': 250}
 
         """
-        return self.call('get_chain_properties', api='database_api')
+        return self.call("get_chain_properties", api="database_api")
 
     def get_feed_history(self):
         """ Get the hourly averages of witness reported HIVE/HBD prices.
@@ -452,7 +455,7 @@ class Hived(HttpClient):
               {'base': '0.093 HBD', 'quote': '1.010 HIVE'},
 
         """
-        return self.call('get_feed_history', api='database_api')
+        return self.call("get_feed_history", api="database_api")
 
     def get_current_median_history_price(self):
         """ Get the average HIVE/HBD price.
@@ -464,12 +467,11 @@ class Hived(HttpClient):
             {'base': '0.093 HBD', 'quote': '1.010 HIVE'}
 
         """
-        return self.call(
-            'get_current_median_history_price', api='database_api')
+        return self.call("get_current_median_history_price", api="database_api")
 
     def get_witness_schedule(self):
         """ get_witness_schedule """
-        return self.call('get_witness_schedule', api='database_api')
+        return self.call("get_witness_schedule", api="database_api")
 
     def get_hardfork_version(self):
         """ Get the current version of the chain.
@@ -478,11 +480,11 @@ class Hived(HttpClient):
             This is not the same as latest minor version.
 
         """
-        return self.call('get_hardfork_version', api='database_api')
+        return self.call("get_hardfork_version", api="database_api")
 
     def get_next_scheduled_hardfork(self):
         """ get_next_scheduled_hardfork """
-        return self.call('get_next_scheduled_hardfork', api='database_api')
+        return self.call("get_next_scheduled_hardfork", api="database_api")
 
     def get_accounts(self, account_names):
         """ Lookup account information such as user profile, public keys,
@@ -492,17 +494,15 @@ class Hived(HttpClient):
         multiple accounts at the time.
 
         """
-        return self.call('get_accounts', account_names, api='database_api')
+        return self.call("get_accounts", account_names, api="database_api")
 
     def get_account_references(self, account_id):
         """ get_account_references """
-        return self.call(
-            'get_account_references', account_id, api='database_api')
+        return self.call("get_account_references", account_id, api="database_api")
 
     def lookup_account_names(self, account_names):
         """ lookup_account_names """
-        return self.call(
-            'lookup_account_names', account_names, api='database_api')
+        return self.call("lookup_account_names", account_names, api="database_api")
 
     def lookup_accounts(self, after, limit):
         """Get a list of usernames from all registered accounts.
@@ -518,16 +518,15 @@ class Hived(HttpClient):
             list: List of usernames in requested chunk.
 
         """
-        return self.call('lookup_accounts', after, limit, api='database_api')
+        return self.call("lookup_accounts", after, limit, api="database_api")
 
     def get_account_count(self):
         """ How many accounts are currently registered on Hive? """
-        return self.call('get_account_count', api='database_api')
+        return self.call("get_account_count", api="database_api")
 
     def get_conversion_requests(self, account):
         """ get_conversion_requests """
-        return self.call(
-            'get_conversion_requests', account, api='database_api')
+        return self.call("get_conversion_requests", account, api="database_api")
 
     def get_account_history(self, account, index_from, limit):
         """ History of all operations for a given account.
@@ -617,40 +616,32 @@ class Hived(HttpClient):
 
         """
         return self.call(
-            'get_account_history',
-            account,
-            index_from,
-            limit,
-            api='database_api')
+            "get_account_history", account, index_from, limit, api="database_api"
+        )
 
     def get_owner_history(self, account):
         """ get_owner_history """
-        return self.call('get_owner_history', account, api='database_api')
+        return self.call("get_owner_history", account, api="database_api")
 
     def get_recovery_request(self, account):
         """ get_recovery_request """
-        return self.call('get_recovery_request', account, api='database_api')
+        return self.call("get_recovery_request", account, api="database_api")
 
     def get_escrow(self, from_account, escrow_id):
         """ get_escrow """
-        return self.call(
-            'get_escrow', from_account, escrow_id, api='database_api')
+        return self.call("get_escrow", from_account, escrow_id, api="database_api")
 
     def get_withdraw_routes(self, account, withdraw_route_type):
         """ get_withdraw_routes """
         return self.call(
-            'get_withdraw_routes',
-            account,
-            withdraw_route_type,
-            api='database_api')
+            "get_withdraw_routes", account, withdraw_route_type, api="database_api"
+        )
 
     def get_account_bandwidth(self, account, bandwidth_type):
         """ get_account_bandwidth """
         return self.call(
-            'get_account_bandwidth',
-            account,
-            bandwidth_type,
-            api='database_api')
+            "get_account_bandwidth", account, bandwidth_type, api="database_api"
+        )
 
     def get_order_book(self, limit):
         """ Get the internal market order book.
@@ -700,11 +691,11 @@ class Hived(HttpClient):
 
 
         """
-        return self.call('get_order_book', limit, api='database_api')
+        return self.call("get_order_book", limit, api="database_api")
 
     def get_open_orders(self, account):
         """ get_open_orders """
-        return self.call('get_open_orders', account, api='database_api')
+        return self.call("get_open_orders", account, api="database_api")
 
     def get_liquidity_queue(self, start_account, limit):
         """ Get the liquidity queue.
@@ -716,40 +707,39 @@ class Hived(HttpClient):
 
         """
         return self.call(
-            'get_liquidity_queue', start_account, limit, api='database_api')
+            "get_liquidity_queue", start_account, limit, api="database_api"
+        )
 
     def get_transaction_hex(self, signed_transaction):
         """ get_transaction_hex """
-        return self.call(
-            'get_transaction_hex', signed_transaction, api='database_api')
+        return self.call("get_transaction_hex", signed_transaction, api="database_api")
 
     def get_transaction(self, transaction_id):
         """ get_transaction """
-        return self.call('get_transaction', transaction_id, api='database_api')
+        return self.call("get_transaction", transaction_id, api="database_api")
 
-    def get_required_signatures(self, signed_transaction,
-                                available_keys):
+    def get_required_signatures(self, signed_transaction, available_keys):
         """ get_required_signatures """
         return self.call(
-            'get_required_signatures',
+            "get_required_signatures",
             signed_transaction,
             available_keys,
-            api='database_api')
+            api="database_api",
+        )
 
     def get_potential_signatures(self, signed_transaction):
         """ get_potential_signatures """
         return self.call(
-            'get_potential_signatures', signed_transaction, api='database_api')
+            "get_potential_signatures", signed_transaction, api="database_api"
+        )
 
     def verify_authority(self, signed_transaction):
         """ verify_authority """
-        return self.call(
-            'verify_authority', signed_transaction, api='database_api')
+        return self.call("verify_authority", signed_transaction, api="database_api")
 
     def verify_account_authority(self, account, keys):
         """ verify_account_authority """
-        return self.call(
-            'verify_account_authority', account, keys, api='database_api')
+        return self.call("verify_account_authority", account, keys, api="database_api")
 
     def get_active_votes(self, author, permlink):
         """ Get all votes for the given post.
@@ -787,8 +777,7 @@ class Hived(HttpClient):
                  'voter': 'flourish',
                  'weight': '2334690471157'}]
         """
-        return self.call(
-            'get_active_votes', author, permlink, api='database_api')
+        return self.call("get_active_votes", author, permlink, api="database_api")
 
     def get_account_votes(self, account):
         """ All votes the given account ever made.
@@ -810,214 +799,200 @@ class Hived(HttpClient):
 
 
         """
-        return self.call('get_account_votes', account, api='database_api')
+        return self.call("get_account_votes", account, api="database_api")
 
     def get_content(self, author, permlink):
         """ get_content """
-        return self.call('get_content', author, permlink, api='database_api')
+        return self.call("get_content", author, permlink, api="database_api")
 
     def get_content_replies(self, author, permlink):
         """ get_content_replies """
-        return self.call(
-            'get_content_replies', author, permlink, api='database_api')
+        return self.call("get_content_replies", author, permlink, api="database_api")
 
     def get_discussions_by_author_before_date(
-            self, author, start_permlink, before_date,
-            limit):
+        self, author, start_permlink, before_date, limit
+    ):
         """ get_discussions_by_author_before_date """
         return self.call(
-            'get_discussions_by_author_before_date',
+            "get_discussions_by_author_before_date",
             author,
             start_permlink,
             before_date,
             limit,
-            api='database_api')
+            api="database_api",
+        )
 
-    def get_replies_by_last_update(self, account, start_permlink,
-                                   limit):
+    def get_replies_by_last_update(self, account, start_permlink, limit):
         """ get_replies_by_last_update """
         return self.call(
-            'get_replies_by_last_update',
+            "get_replies_by_last_update",
             account,
             start_permlink,
             limit,
-            api='database_api')
+            api="database_api",
+        )
 
     def get_witnesses(self, witness_ids):
         """ get_witnesses """
-        return self.call('get_witnesses', witness_ids, api='database_api')
+        return self.call("get_witnesses", witness_ids, api="database_api")
 
     def get_witness_by_account(self, account):
         """ get_witness_by_account """
-        return self.call('get_witness_by_account', account, api='database_api')
+        return self.call("get_witness_by_account", account, api="database_api")
 
     def get_witnesses_by_vote(self, from_account, limit):
         """ get_witnesses_by_vote """
         return self.call(
-            'get_witnesses_by_vote', from_account, limit, api='database_api')
+            "get_witnesses_by_vote", from_account, limit, api="database_api"
+        )
 
     def lookup_witness_accounts(self, from_account, limit):
         """ lookup_witness_accounts """
         return self.call(
-            'lookup_witness_accounts', from_account, limit, api='database_api')
+            "lookup_witness_accounts", from_account, limit, api="database_api"
+        )
 
     def get_witness_count(self):
         """ get_witness_count """
-        return self.call('get_witness_count', api='database_api')
+        return self.call("get_witness_count", api="database_api")
 
     def get_active_witnesses(self):
         """ Get a list of currently active witnesses. """
-        return self.call('get_active_witnesses', api='database_api')
+        return self.call("get_active_witnesses", api="database_api")
 
-    def get_vesting_delegations(self, account, from_account,
-                                limit):
+    def get_vesting_delegations(self, account, from_account, limit):
         """ get_vesting_delegations """
         return self.call(
-            'get_vesting_delegations',
-            account,
-            from_account,
-            limit,
-            api='database_api')
+            "get_vesting_delegations", account, from_account, limit, api="database_api"
+        )
 
     def login(self, username, password):
         """ login """
-        return self.call('login', username, password, api='login_api')
+        return self.call("login", username, password, api="login_api")
 
     def get_api_by_name(self, api_name):
         """ get_api_by_name """
-        return self.call('get_api_by_name', api_name, api='login_api')
+        return self.call("get_api_by_name", api_name, api="login_api")
 
     def get_version(self):
         """ Get hived version of the node currently connected to. """
-        return self.call('get_version', api='database_api')
+        return self.call("get_version", api="database_api")
 
-    def get_followers(self, account, start_follower,
-                      follow_type, limit):
+    def get_followers(self, account, start_follower, follow_type, limit):
         """ get_followers """
         return self.call(
-            'get_followers',
+            "get_followers",
             account,
             start_follower,
             follow_type,
             limit,
-            api='follow_api')
+            api="follow_api",
+        )
 
-    def get_following(self, account, start_follower,
-                      follow_type, limit):
+    def get_following(self, account, start_follower, follow_type, limit):
         """ get_following """
         return self.call(
-            'get_following',
+            "get_following",
             account,
             start_follower,
             follow_type,
             limit,
-            api='follow_api')
+            api="follow_api",
+        )
 
     def get_follow_count(self, account):
         """ get_follow_count """
-        return self.call('get_follow_count', account, api='follow_api')
+        return self.call("get_follow_count", account, api="follow_api")
 
     def get_feed_entries(self, account, entry_id, limit):
         """ get_feed_entries """
-        return self.call(
-            'get_feed_entries', account, entry_id, limit, api='follow_api')
+        return self.call("get_feed_entries", account, entry_id, limit, api="follow_api")
 
     def get_feed(self, account, entry_id, limit):
         """ get_feed """
-        return self.call(
-            'get_feed', account, entry_id, limit, api='follow_api')
+        return self.call("get_feed", account, entry_id, limit, api="follow_api")
 
     def get_blog_entries(self, account, entry_id, limit):
         """ get_blog_entries """
-        return self.call(
-            'get_blog_entries', account, entry_id, limit, api='follow_api')
+        return self.call("get_blog_entries", account, entry_id, limit, api="follow_api")
 
     def get_blog(self, account, entry_id, limit):
         """ get_blog """
-        return self.call(
-            'get_blog', account, entry_id, limit, api='follow_api')
+        return self.call("get_blog", account, entry_id, limit, api="follow_api")
 
     def get_account_reputations(self, account, limit):
         """ get_account_reputations """
-        return self.call(
-            'get_account_reputations', account, limit, api='follow_api')
+        return self.call("get_account_reputations", account, limit, api="follow_api")
 
     def get_reblogged_by(self, author, permlink):
         """ get_reblogged_by """
-        return self.call(
-            'get_reblogged_by', author, permlink, api='follow_api')
+        return self.call("get_reblogged_by", author, permlink, api="follow_api")
 
     def get_blog_authors(self, blog_account):
         """ get_blog_authors """
-        return self.call('get_blog_authors', blog_account, api='follow_api')
+        return self.call("get_blog_authors", blog_account, api="follow_api")
 
     def broadcast_transaction(self, signed_transaction):
         """ broadcast_transaction """
         return self.call(
-            'broadcast_transaction',
-            signed_transaction,
-            api='network_broadcast_api')
+            "broadcast_transaction", signed_transaction, api="network_broadcast_api"
+        )
 
-    def broadcast_transaction_synchronous(
-            self, signed_transaction):
+    def broadcast_transaction_synchronous(self, signed_transaction):
         """ broadcast_transaction_synchronous """
         return self.call(
-            'broadcast_transaction_synchronous',
+            "broadcast_transaction_synchronous",
             signed_transaction,
-            api='network_broadcast_api')
+            api="network_broadcast_api",
+        )
 
     def broadcast_block(self, block):
         """ broadcast_block """
-        return self.call('broadcast_block', block, api='network_broadcast_api')
+        return self.call("broadcast_block", block, api="network_broadcast_api")
 
     def set_max_block_age(self, max_block_age):
         """ set_max_block_age """
         return self.call(
-            'set_max_block_age', max_block_age, api='network_broadcast_api')
+            "set_max_block_age", max_block_age, api="network_broadcast_api"
+        )
 
     def get_ticker(self):
         """ Returns the market ticker for the internal HBD:HIVE market. """
-        return self.call('get_ticker', api='market_history_api')
+        return self.call("get_ticker", api="market_history_api")
 
     def get_volume(self):
         """ Returns the market volume for the past 24 hours. """
-        return self.call('get_volume', api='market_history_api')
+        return self.call("get_volume", api="market_history_api")
 
-    def get_trade_history(self, start, end,
-                          limit):
+    def get_trade_history(self, start, end, limit):
         """ Returns the trade history for the internal HBD:HIVE market. """
         return self.call(
-            'get_trade_history', start, end, limit, api='market_history_api')
+            "get_trade_history", start, end, limit, api="market_history_api"
+        )
 
     def get_recent_trades(self, limit):
         """ Returns the N most recent trades for the internal HBD:HIVE
         market. """
 
-        return self.call('get_recent_trades', limit, api='market_history_api')
+        return self.call("get_recent_trades", limit, api="market_history_api")
 
-    def get_market_history(self, bucket_seconds, start,
-                           end):
+    def get_market_history(self, bucket_seconds, start, end):
         """ Returns the market history for the internal HBD:HIVE market. """
         return self.call(
-            'get_market_history',
-            bucket_seconds,
-            start,
-            end,
-            api='market_history_api')
+            "get_market_history", bucket_seconds, start, end, api="market_history_api"
+        )
 
     def get_market_history_buckets(self):
         """ Returns the bucket seconds being tracked by the plugin. """
-        return self.call(
-            'get_market_history_buckets', api='market_history_api')
+        return self.call("get_market_history_buckets", api="market_history_api")
 
     def get_key_references(self, public_keys):
         """ get_key_references """
         if type(public_keys) == str:
             public_keys = [public_keys]
-        return self.call(
-            'get_key_references', public_keys, api='account_by_key_api')
+        return self.call("get_key_references", public_keys, api="account_by_key_api")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     h = Hived()
     print(h.get_account_count())
